#[non_exhaustive]pub enum ProbeBuilderError {
ProbeBuild(ProbeError),
MutuallyExclusive(String),
Required(String),
}Expand description
ProbeBuilder runtime errors.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ProbeBuild(ProbeError)
Error while creating a new Probe instance.
MutuallyExclusive(String)
Error if two mutually exclusive setter functions are called.
Required(String)
Error if failed to call a mandatory setter function.